"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
/*
 * Copyright (c) 2016 VMware, Inc. All Rights Reserved.
 * This software is released under MIT license.
 * The full license information can be found in LICENSE in the root directory of this project.
 */
var core_1 = require("@angular/core");
var inventory_1 = require("../inventory/inventory");
var color_filter_1 = require("../utils/color-filter");
var pokemon_comparator_1 = require("../utils/pokemon-comparator");
var pokemon_filter_1 = require("../utils/pokemon-filter");
var DatagridFullDemo = (function () {
    function DatagridFullDemo(inventory) {
        this.inventory = inventory;
        this.options = {
            totalUsers: 103,
            pageSize: "10",
            selectable: true,
            loremIpsum: false,
            server: false,
            latency: "500",
        };
        this.resetting = true;
        // Server-driven specific
        this.isServerDriven = false;
        this.loading = true;
        this.pokemonComparator = new pokemon_comparator_1.PokemonComparator();
        this.pokemonFilter = new pokemon_filter_1.PokemonFilter();
        this.reset();
    }
    DatagridFullDemo.prototype.reset = function () {
        var _this = this;
        this.resetting = true;
        this.loading = true;
        // Timeout hack to make sure we completely reset the datagrid
        setTimeout(function () {
            _this.inventory.size = _this.options.totalUsers;
            _this.currentPageSize = Number.parseInt(_this.options.pageSize);
            _this.selected = _this.options.selectable ? [] : null;
            _this.loremIpsumColumn = _this.options.loremIpsum;
            _this.isServerDriven = _this.options.server;
            _this.inventory.latency = Number.parseInt(_this.options.latency);
            _this.inventory.reset();
            if (_this.isServerDriven) {
                _this.users = [];
            }
            else {
                _this.users = _this.inventory.all;
            }
            _this.resetting = false;
        });
    };
    DatagridFullDemo.prototype.refresh = function (state) {
        var _this = this;
        if (!this.isServerDriven) {
            return;
        }
        this.loading = true;
        var filters = {};
        if (state.filters) {
            for (var _i = 0, _a = state.filters; _i < _a.length; _i++) {
                var filter = _a[_i];
                if (filter instanceof color_filter_1.ColorFilter) {
                    filters["color"] = filter.listSelected();
                }
                else {
                    var _b = filter, property = _b.property, value = _b.value;
                    filters[property] = [value];
                }
            }
        }
        this.inventory.filter(filters)
            .sort(state.sort)
            .fetch(state.page && state.page.from, state.page && state.page.size)
            .then(function (result) {
            _this.users = result.users;
            _this.total = result.length;
            _this.loading = false;
        });
    };
    DatagridFullDemo = __decorate([
        core_1.Component({
            selector: "clr-datagrid-full-demo",
            providers: [inventory_1.Inventory],
            template: "\n      <!--\n        ~ Copyright (c) 2016 VMware, Inc. All Rights Reserved.\n        ~ This software is released under MIT license.\n        ~ The full license information can be found in LICENSE in the root directory of this project.\n        -->\n\n      <h2>Full Datagrid demo</h2>\n\n      <form (submit)=\"$event.preventDefault(); reset()\" ngNoForm>\n          <div class=\"form-group\">\n              <label for=\"total\">Number of users</label>\n              <input type=\"number\" class=\"inline-control\" id=\"total\" name=\"total\" [(ngModel)]=\"options.totalUsers\">\n          </div>\n\n          <div class=\"form-group\">\n              <label for=\"page-size\">Rows per page</label>\n              <div class=\"select\">\n                  <select id=\"page-size\" name=\"page-size\" [(ngModel)]=\"options.pageSize\">\n                      <option value=\"0\">No pagination</option>\n                      <option value=\"10\">10</option>\n                      <option value=\"25\">25</option>\n                      <option value=\"100\">100</option>\n                  </select>\n              </div>\n          </div>\n\n          <div class=\"form-group\">\n              <clr-checkbox [(ngModel)]=\"options.selectable\" [clrInline]=\"true\">Selectable</clr-checkbox>\n              <clr-checkbox [(ngModel)]=\"options.loremIpsum\" [clrInline]=\"true\">Multi-line text</clr-checkbox>\n          </div>\n\n          <div class=\"form-group\">\n              <clr-checkbox [(ngModel)]=\"options.server\">Server-driven</clr-checkbox>\n          </div>\n\n          <div class=\"form-group\" *ngIf=\"options.server\">\n              <label for=\"latency\">Latency</label>\n              <div class=\"select\">\n                  <select id=\"latency\" name=\"latency\" [(ngModel)]=\"options.latency\">\n                      <option value=\"0\">0 ms</option>\n                      <option value=\"100\">100ms</option>\n                      <option value=\"200\">200ms</option>\n                      <option value=\"500\">500ms</option>\n                      <option value=\"1000\">1s</option>\n                      <option value=\"2000\">2s</option>\n                  </select>\n              </div>\n          </div>\n\n          <button type=\"submit\" class=\"btn btn-primary\">Apply</button>\n      </form>\n\n      <div *ngIf=\"!resetting\">\n          <div *ngIf=\"selected\" class=\"card card-block\">\n              <p class=\"card-text username-list\">\n                  Selected users:\n                  <em *ngIf=\"selected.length == 0\">No user selected.</em>\n                  <span class=\"username\" *ngFor=\"let user of selected\">{{user.name}}</span>\n              </p>\n          </div>\n\n          <clr-datagrid *ngIf=\"!isServerDriven\" [(clrDgSelected)]=\"selected\">\n              <clr-dg-column>User ID</clr-dg-column>\n              <clr-dg-column [clrDgField]=\"'name'\">Name</clr-dg-column>\n              <clr-dg-column [clrDgField]=\"'creation'\">Creation date</clr-dg-column>\n              <clr-dg-column [clrDgSortBy]=\"pokemonComparator\">\n                  Pokemon\n                  <clr-dg-string-filter [clrDgStringFilter]=\"pokemonFilter\"></clr-dg-string-filter>\n              </clr-dg-column>\n              <clr-dg-column [clrDgField]=\"'color'\">\n                  Favorite color\n                  <clr-dg-filter [clrDgFilter]=\"colorFilter\">\n                      <clr-datagrid-color-filter-demo #colorFilter class=\"color-filter\">\n                      </clr-datagrid-color-filter-demo>\n                  </clr-dg-filter>\n              </clr-dg-column>\n              <clr-dg-column *ngIf=\"loremIpsumColumn\">Multi-line text</clr-dg-column>\n\n              <clr-dg-placeholder>No users found</clr-dg-placeholder>\n              <clr-dg-row *clrDgItems=\"let user of users\" [clrDgItem]=\"user\">\n                  <clr-dg-cell>{{user.id}}</clr-dg-cell>\n                  <clr-dg-cell>{{user.name}}</clr-dg-cell>\n                  <clr-dg-cell>{{user.creation | date}}</clr-dg-cell>\n                  <clr-dg-cell>{{user.pokemon.name}}</clr-dg-cell>\n                  <clr-dg-cell>\n                      <span class=\"color-square\" [style.backgroundColor]=\"user.color\"></span>\n                  </clr-dg-cell>\n                  <clr-dg-cell class=\"lorem-ipsum\" *ngIf=\"loremIpsumColumn\">\n                      Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed tortor tellus,\n                      tincidunt eget mauris molestie, ullamcorper facilisis lacus. Vivamus sagittis\n                      suscipit libero, et tristique justo consectetur eget.\n                  </clr-dg-cell>\n              </clr-dg-row>\n\n              <clr-dg-footer>\n                  {{pagination.firstItem + 1}} - {{pagination.lastItem + 1}}\n                  of {{pagination.totalItems}} users\n                  <clr-dg-pagination #pagination [clrDgPageSize]=\"currentPageSize\"></clr-dg-pagination>\n              </clr-dg-footer>\n          </clr-datagrid>\n\n          <clr-datagrid *ngIf=\"isServerDriven\" [(clrDgSelected)]=\"selected\"\n                        (clrDgRefresh)=\"refresh($event)\" [clrDgLoading]=\"loading\">\n              <clr-dg-column>User ID</clr-dg-column>\n              <clr-dg-column [clrDgField]=\"'name'\">Name</clr-dg-column>\n              <clr-dg-column [clrDgField]=\"'creation'\">Creation date</clr-dg-column>\n              <clr-dg-column [clrDgField]=\"'pokemon'\">Pokemon</clr-dg-column>\n              <clr-dg-column [clrDgField]=\"'color'\">\n                  Favorite color\n                  <clr-dg-filter [clrDgFilter]=\"colorFilter\">\n                      <clr-datagrid-color-filter-demo #colorFilter class=\"color-filter\">\n                      </clr-datagrid-color-filter-demo>\n                  </clr-dg-filter>\n              </clr-dg-column>\n              <clr-dg-column *ngIf=\"loremIpsumColumn\">Multi-line text</clr-dg-column>\n\n              <clr-dg-placeholder>No users found</clr-dg-placeholder>\n              <clr-dg-row *ngFor=\"let user of users\" [clrDgItem]=\"user\">\n                  <clr-dg-cell>{{user.id}}</clr-dg-cell>\n                  <clr-dg-cell>{{user.name}}</clr-dg-cell>\n                  <clr-dg-cell>{{user.creation | date}}</clr-dg-cell>\n                  <clr-dg-cell>{{user.pokemon.name}}</clr-dg-cell>\n                  <clr-dg-cell>\n                      <span class=\"color-square\" [style.backgroundColor]=\"user.color\"></span>\n                  </clr-dg-cell>\n                  <clr-dg-cell class=\"lorem-ipsum\" *ngIf=\"loremIpsumColumn\">\n                      Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed tortor tellus,\n                      tincidunt eget mauris molestie, ullamcorper facilisis lacus. Vivamus sagittis\n                      suscipit libero, et tristique justo consectetur eget.\n                  </clr-dg-cell>\n              </clr-dg-row>\n\n              <clr-dg-footer>\n                  {{pagination.firstItem + 1}} - {{pagination.lastItem + 1}}\n                  of {{total}} users\n                  <clr-dg-pagination #pagination [clrDgPageSize]=\"currentPageSize\"\n                                     [clrDgTotalItems]=\"total\"></clr-dg-pagination>\n              </clr-dg-footer>\n          </clr-datagrid>\n      </div>\n    ",
            styles: ["\n      .clr-example{margin-top:24px}.clr-example .main-container{height:auto;padding-top:0;background:#fff}.clr-example .main-container .content-area{overflow-y:hidden}.clr-example.squeeze{padding:48px}.modal.static{position:relative;padding:72px}.modal-backdrop.static{position:absolute;top:0;right:0;bottom:0;left:0}.modal-icon{float:left;color:#60b515;font-size:42px;margin-right:12px}.backdrop-example-container{position:relative;padding:24px}.bump-down{margin-top:24px !important}:not(pre)>code[class*=\"language-\"],pre[class*=\"language-\"],pre,code[class*=\"language-\"]{background:transparent}.color-square{display:inline-block;vertical-align:text-bottom;height:14px;width:14px;border:1px solid black;border-radius:4px}.color-filter{display:block;width:100px}.color-selectable{cursor:pointer;margin:2px;opacity:0.2}.color-selectable:hover,.color-selectable.color-selected{opacity:1}.lorem-ipsum{max-width:300px}.username-list{margin-bottom:0}.username-list .username:not(:last-child)::after{content:\", \"}.username-list .username:last-child::after{content:\".\"}\n    "]
        }), 
        __metadata('design:paramtypes', [inventory_1.Inventory])
    ], DatagridFullDemo);
    return DatagridFullDemo;
}());
exports.DatagridFullDemo = DatagridFullDemo;
