"use strict";
var values_1 = require("./values");
var Inventory = (function () {
    function Inventory() {
        this.size = 100;
        this.latency = 0;
    }
    Object.defineProperty(Inventory.prototype, "all", {
        get: function () {
            return this._all.slice();
        },
        enumerable: true,
        configurable: true
    });
    Inventory.prototype.reset = function () {
        this._all = [];
        for (var i = 0; i < this.size; i++) {
            this._all.push({
                id: randomInt(100000),
                name: values_1.NAMES[randomInt(values_1.NAMES.length)],
                creation: new Date(values_1.BEGINNING + randomInt(values_1.NOW - values_1.BEGINNING)),
                color: values_1.COLORS[randomInt(values_1.COLORS.length)],
                pokemon: values_1.POKEMONS[randomInt(values_1.POKEMONS.length)]
            });
        }
    };
    Inventory.prototype._checkCurrentQuery = function () {
        if (!this._currentQuery) {
            this._currentQuery = this._all.slice();
        }
    };
    Inventory.prototype.filter = function (filters) {
        this._checkCurrentQuery();
        if (filters) {
            var _loop_1 = function(key) {
                if (filters[key].length === 0) {
                    return "continue";
                }
                var getFilterProperty = function (user) { return "" + user[key]; };
                if (key === "pokemon") {
                    getFilterProperty = function (user) { return user.pokemon.name; };
                }
                var lowerCase = filters[key].map(function (value) { return value.toLowerCase(); });
                this_1._currentQuery = this_1._currentQuery.filter(function (user) {
                    for (var _i = 0, lowerCase_1 = lowerCase; _i < lowerCase_1.length; _i++) {
                        var value = lowerCase_1[_i];
                        if (getFilterProperty(user).toLowerCase().indexOf(value) >= 0) {
                            return true;
                        }
                    }
                    return false;
                });
            };
            var this_1 = this;
            for (var key in filters) {
                _loop_1(key);
            }
        }
        return this;
    };
    Inventory.prototype.sort = function (sort) {
        this._checkCurrentQuery();
        if (sort && sort.by) {
            var getSortProperty_1 = function (user) { return user[sort.by]; };
            if (sort.by === "pokemon") {
                getSortProperty_1 = function (user) { return user.pokemon.number; };
            }
            this._currentQuery.sort(function (a, b) {
                var comp = 0;
                var propA = getSortProperty_1(a), propB = getSortProperty_1(b);
                if (propA < propB) {
                    comp = -1;
                }
                else if (propA > propB) {
                    comp = 1;
                }
                if (sort.reverse) {
                    comp = -comp;
                }
                return comp;
            });
        }
        return this;
    };
    Inventory.prototype.fetch = function (skip, limit) {
        if (skip === void 0) { skip = 0; }
        if (limit === void 0) { limit = this._currentQuery.length; }
        var result = {
            users: this._currentQuery.slice(skip, skip + limit),
            length: this._currentQuery.length
        };
        this._currentQuery = null;
        return this._fakeHttp(result);
    };
    Inventory.prototype._fakeHttp = function (result) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            setTimeout(function () { return resolve(result); }, _this.latency);
        });
    };
    return Inventory;
}());
exports.Inventory = Inventory;
function randomInt(max) {
    return Math.floor(Math.random() * max);
}
