"use strict";
/*
 * Copyright (c) 2016 VMware, Inc. All Rights Reserved.
 * This software is released under MIT license.
 * The full license information can be found in LICENSE in the root directory of this project.
 */
exports.EXAMPLES = {
    stateInterface: "\ninterface State {\n    page?: {\n        from?: number;\n        to?: number;\n        size?: number;\n    }\n    sort?: {\n        by: string | Comparator<any>\n        reverse: boolean;\n    };\n    filters?: ({property: string, value: string} | Filter<any>)[];\n}\n",
    serverDrivenTS: "\nimport {State} from \"clarity-angular\";\n\nclass MyComponent {\n    users: User[];\n    total: number;\n    loading: boolean = true;\n\n    refresh(state: State) {\n        this.loading = true;\n        // We convert the filters from an array to a map,\n        // because that's what our backend-calling service is expecting\n        let filters:{[prop:string]: any[]} = {};\n        if (state.filters) {\n            for (let filter of state.filters) {\n                let {property, value} = <{property: string, value: string}>filter;\n                filters[property] = [value];\n            }\n        }\n        this.inventory.filter(filters)\n            .sort(<{by: string, reverse: boolean}>state.sort)\n            .fetch(state.page.from, state.page.size)\n            .then((result: FetchResult) => {\n                this.users = result.users;\n                this.total = result.length;\n                this.loading = false;\n            });\n    }\n}\n",
    serverDrivenHTML: "\n<clr-datagrid (clrDgRefresh)=\"refresh($event)\" [clrDgLoading]=\"loading\">\n    <clr-dg-column>User ID</clr-dg-column>\n    <clr-dg-column [clrDgField]=\"'name'\">Name</clr-dg-column>\n    <clr-dg-column [clrDgField]=\"'creation'\">Creation date</clr-dg-column>\n    <clr-dg-column [clrDgField]=\"'pokemon'\">Pokemon</clr-dg-column>\n    <clr-dg-column [clrDgField]=\"'color'\">Favorite color</clr-dg-column>\n\n    <clr-dg-row *ngFor=\"let user of users\">\n        <clr-dg-cell>{{user.id}}</clr-dg-cell>\n        <clr-dg-cell>{{user.name}}</clr-dg-cell>\n        <clr-dg-cell>{{user.creation | date}}</clr-dg-cell>\n        <clr-dg-cell>{{user.pokemon.name}}</clr-dg-cell>\n        <clr-dg-cell>\n            <span class=\"color-square\" [style.backgroundColor]=\"user.color\"></span>\n        </clr-dg-cell>\n    </clr-dg-row>\n\n    <clr-dg-footer>\n        {{pagination.firstItem + 1}} - {{pagination.lastItem + 1}}\n        of {{total}} users\n        <clr-dg-pagination #pagination [clrDgTotalItems]=\"total\"></clr-dg-pagination>\n    </clr-dg-footer>\n</clr-datagrid>\n"
};
