"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
/*
 * Copyright (c) 2016 VMware, Inc. All Rights Reserved.
 * This software is released under MIT license.
 * The full license information can be found in LICENSE in the root directory of this project.
 */
var core_1 = require("@angular/core");
var inventory_1 = require("../inventory/inventory");
var examples_1 = require("./examples");
var DatagridServerDrivenDemo = (function () {
    function DatagridServerDrivenDemo(inventory) {
        this.inventory = inventory;
        this.examples = examples_1.EXAMPLES;
        this.loading = true;
        inventory.size = 103;
        this.inventory.latency = 500;
        inventory.reset();
    }
    DatagridServerDrivenDemo.prototype.refresh = function (state) {
        var _this = this;
        this.loading = true;
        var filters = {};
        if (state.filters) {
            for (var _i = 0, _a = state.filters; _i < _a.length; _i++) {
                var filter = _a[_i];
                var _b = filter, property = _b.property, value = _b.value;
                filters[property] = [value];
            }
        }
        this.inventory.filter(filters)
            .sort(state.sort)
            .fetch(state.page.from, state.page.size)
            .then(function (result) {
            _this.users = result.users;
            _this.total = result.length;
            _this.loading = false;
        });
    };
    DatagridServerDrivenDemo = __decorate([
        core_1.Component({
            selector: "clr-datagrid-server-driven-demo",
            providers: [inventory_1.Inventory],
            template: "\n      <!--\n        ~ Copyright (c) 2016 VMware, Inc. All Rights Reserved.\n        ~ This software is released under MIT license.\n        ~ The full license information can be found in LICENSE in the root directory of this project.\n        -->\n\n      <h2>Server-driven datagrid</h2>\n\n      <p>\n          When dealing with large amounts of data or heavy processing, a datagrid often has access the\n          currently displayed data only, requesting only the necessary pieces from the server. This is a\n          very common case that we fully support.\n      </p>\n      <p>\n          We expose events and hooks on all parts of the datagrid to make sure you can trigger any\n          requests you need based on precise user actions. But an important thing to note is that when\n          the server does handle pagination, it needs to also deal with sorting and filtering,\n          because all three are tightly coupled. In light of this, we decided to expose a single global\n          output <code class=\"clr-code\">(clrDgRefresh)</code> that emits the current \"state\" of the\n          datagrid whenever it changes due to a user action or an external one. This state has the\n          following format:\n      </p>\n      <clr-example [clrCode]=\"examples.stateInterface\" clrLanguage=\"typescript\"></clr-example>\n      <p>\n          It contains all the information you need to send to the server in order to get the slice of\n          data currently displayed. It even contains redundant information (\n          <code class=\"clr-code\">page.to</code> and <code class=\"clr-code\">page.size</code> for instance),\n          to make sure you have access to the most practical for you without extra processing.\n      </p>\n      <p>\n          One important thing to note is that since you don't have all the data available at once, you\n          cannot use the smart iterator\n          <code class=\"clr-code\">*clrDgItems</code>: it would sort, filter and paginate a subset of the\n          data that has already gone through all that. So all you need to do is to go back to a simple\n          <code class=\"clr-code\">*ngFor</code>, which we support.\n      </p>\n      <p>\n          Finally, since server calls are involved, we need some way of notifying the user that his\n          action has been acknowledged and that we are currently working on it. To this effect, we\n          provide an input <code class=\"clr-code\">[clrDgLoading]</code> that you can use to display the\n          datagrid in a loading state, while fetching data.\n      </p>\n\n      <p>\n          Here is an example showcasing all this with a fake server latency of 500ms. It also\n          demonstrates how to adapt the state we emit when it does not match exactly your server's API:\n          in this example, the filters are re-formatted from an array to a map.\n      </p>\n\n      <clr-datagrid (clrDgRefresh)=\"refresh($event)\" [clrDgLoading]=\"loading\">\n          <clr-dg-column>User ID</clr-dg-column>\n          <clr-dg-column [clrDgField]=\"'name'\">Name</clr-dg-column>\n          <clr-dg-column [clrDgField]=\"'creation'\">Creation date</clr-dg-column>\n          <clr-dg-column [clrDgField]=\"'pokemon'\">Pokemon</clr-dg-column>\n          <clr-dg-column [clrDgField]=\"'color'\">Favorite color</clr-dg-column>\n\n          <clr-dg-row *ngFor=\"let user of users\">\n              <clr-dg-cell>{{user.id}}</clr-dg-cell>\n              <clr-dg-cell>{{user.name}}</clr-dg-cell>\n              <clr-dg-cell>{{user.creation | date}}</clr-dg-cell>\n              <clr-dg-cell>{{user.pokemon.name}}</clr-dg-cell>\n              <clr-dg-cell>\n                  <span class=\"color-square\" [style.backgroundColor]=\"user.color\"></span>\n              </clr-dg-cell>\n          </clr-dg-row>\n\n          <clr-dg-footer>\n              {{pagination.firstItem + 1}} - {{pagination.lastItem + 1}}\n              of {{total}} users\n              <clr-dg-pagination #pagination [clrDgTotalItems]=\"total\"></clr-dg-pagination>\n          </clr-dg-footer>\n      </clr-datagrid>\n\n      <clr-example [clrCode]=\"examples.serverDrivenTS\" clrLanguage=\"typescript\"></clr-example>\n      <clr-example [clrCode]=\"examples.serverDrivenHTML\" clrLanguage=\"html\"></clr-example>\n    ",
            styles: ["\n      .clr-example{margin-top:24px}.clr-example .main-container{height:auto;padding-top:0;background:#fff}.clr-example .main-container .content-area{overflow-y:hidden}.clr-example.squeeze{padding:48px}.modal.static{position:relative;padding:72px}.modal-backdrop.static{position:absolute;top:0;right:0;bottom:0;left:0}.modal-icon{float:left;color:#60b515;font-size:42px;margin-right:12px}.backdrop-example-container{position:relative;padding:24px}.bump-down{margin-top:24px !important}:not(pre)>code[class*=\"language-\"],pre[class*=\"language-\"],pre,code[class*=\"language-\"]{background:transparent}.color-square{display:inline-block;vertical-align:text-bottom;height:14px;width:14px;border:1px solid black;border-radius:4px}.color-filter{display:block;width:100px}.color-selectable{cursor:pointer;margin:2px;opacity:0.2}.color-selectable:hover,.color-selectable.color-selected{opacity:1}.lorem-ipsum{max-width:300px}.username-list{margin-bottom:0}.username-list .username:not(:last-child)::after{content:\", \"}.username-list .username:last-child::after{content:\".\"}\n    "]
        }), 
        __metadata('design:paramtypes', [inventory_1.Inventory])
    ], DatagridServerDrivenDemo);
    return DatagridServerDrivenDemo;
}());
exports.DatagridServerDrivenDemo = DatagridServerDrivenDemo;
