"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
/*
 * Copyright (c) 2016 VMware, Inc. All Rights Reserved.
 * This software is released under MIT license.
 * The full license information can be found in LICENSE in the root directory of this project.
 */
var core_1 = require("@angular/core");
var inventory_1 = require("../inventory/inventory");
var pokemon_comparator_1 = require("../utils/pokemon-comparator");
var examples_1 = require("./examples");
var DatagridSortingDemo = (function () {
    function DatagridSortingDemo(inventory) {
        this.inventory = inventory;
        this.examples = examples_1.EXAMPLES;
        this.pokemonComparator = new pokemon_comparator_1.PokemonComparator();
        inventory.size = 10;
        inventory.reset();
        this.users = inventory.all;
    }
    DatagridSortingDemo = __decorate([
        core_1.Component({
            selector: "clr-datagrid-sorting-demo",
            providers: [inventory_1.Inventory],
            template: "\n      <!--\n        ~ Copyright (c) 2016 VMware, Inc. All Rights Reserved.\n        ~ This software is released under MIT license.\n        ~ The full license information can be found in LICENSE in the root directory of this project.\n        -->\n\n      <h2>Custom sort</h2>\n\n      <p>\n          Sometimes, the natural sort order for a property is not the relevant one. Sometimes, a column\n          is not even a property on your model but is dynamically generated instead. In these cases,\n          you might want to specify a custom comparator to sort the column according to your needs.\n          This can be done by providing a comparator through the\n          <code class=\"clr-code\">[clrDgSortBy]</code> input, whether or not your column is declared as a\n          <code class=\"clr-code\">clrDgField</code>, and will always take precedence over it if it is.\n      </p>\n      <p>\n          A comparator is just an object that implements a <code class=\"clr-code\">compare</code> method\n          that could be given as parameter to Javascript's native\n          <code class=\"clr-code\">Array.sort()</code> function. In other words, if a and b are two\n          elements being compared, then:\n      </p>\n      <ul>\n          <li>\n              if compare(a, b) is less than 0, a comes first,\n          </li>\n          <li>\n              if compare(a, b) returns 0, leave a and b unchanged with respect to each other, but\n              sorted with respect to all other items,\n          </li>\n          <li>\n              if compare(a, b) is greater than 0, b comes first.\n          </li>\n      </ul>\n      <p>\n          The safest way to check that your types comply with our API is to have your comparator be an\n          instance of a class that implement the <code class=\"clr-code\">Comparator</code> interface\n          provided by Clarity.\n      </p>\n      <div class=\"alert alert-info\">\n          <div class=\"alert-item\">\n              <span class=\"alert-text\">\n                  Why use an object instead of the function directly?\n              </span>\n          </div>\n          <div class=\"alert-item\">\n              <span>\n                  Using an object implementing an interface allows strong type-checking, which is safer\n                  for your application. If your sorting function does not comply with our API, you will\n                  get a clear error during typescript compilation, instead of an obscure one during\n                  runtime.\n              </span>\n          </div>\n          <div class=\"alert-item\">\n              <span>\n                  Admittedly, we could achieve strong typing by exporting a function signature instead\n                  of a whole interface, but not only do interfaces leave room for future features without\n                  forcing breaking changes, they also encourage you to write your business logic\n                  outside of the controller, naturally creating pure Typescript or Javascript \"logic\"\n                  classes, which are far more reusable.\n              </span>\n          </div>\n      </div>\n      <p>\n          In our example, everyone knows pokemons should not be sorted lexicographically, but according\n          to Pok&eacute;dex number.\n      </p>\n\n      <clr-datagrid>\n          <clr-dg-column>User ID</clr-dg-column>\n          <clr-dg-column>Name</clr-dg-column>\n          <clr-dg-column>Creation date</clr-dg-column>\n          <clr-dg-column [clrDgField]=\"'pokemon.name'\"\n                         [clrDgSortBy]=\"pokemonComparator\">Pokemon</clr-dg-column>\n          <clr-dg-column>Favorite color</clr-dg-column>\n\n          <clr-dg-row *clrDgItems=\"let user of users\">\n              <clr-dg-cell>{{user.id}}</clr-dg-cell>\n              <clr-dg-cell>{{user.name}}</clr-dg-cell>\n              <clr-dg-cell>{{user.creation | date}}</clr-dg-cell>\n              <clr-dg-cell>\n                  {{user.pokemon.name}} <span class=\"badge badge-5\">#{{user.pokemon.number}}</span>\n              </clr-dg-cell>\n              <clr-dg-cell>\n                  <span class=\"color-square\" [style.backgroundColor]=\"user.color\"></span>\n              </clr-dg-cell>\n          </clr-dg-row>\n\n          <clr-dg-footer>{{users.length}} users</clr-dg-footer>\n      </clr-datagrid>\n\n      <clr-example [clrCode]=\"examples.sortingTS\" clrLanguage=\"typescript\"></clr-example>\n      <clr-example [clrCode]=\"examples.sortingHTML\" clrLanguage=\"html\"></clr-example>\n    ",
            styles: ["\n      .clr-example{margin-top:24px}.clr-example .main-container{height:auto;padding-top:0;background:#fff}.clr-example .main-container .content-area{overflow-y:hidden}.clr-example.squeeze{padding:48px}.modal.static{position:relative;padding:72px}.modal-backdrop.static{position:absolute;top:0;right:0;bottom:0;left:0}.modal-icon{float:left;color:#60b515;font-size:42px;margin-right:12px}.backdrop-example-container{position:relative;padding:24px}.bump-down{margin-top:24px !important}:not(pre)>code[class*=\"language-\"],pre[class*=\"language-\"],pre,code[class*=\"language-\"]{background:transparent}.color-square{display:inline-block;vertical-align:text-bottom;height:14px;width:14px;border:1px solid black;border-radius:4px}.color-filter{display:block;width:100px}.color-selectable{cursor:pointer;margin:2px;opacity:0.2}.color-selectable:hover,.color-selectable.color-selected{opacity:1}.lorem-ipsum{max-width:300px}.username-list{margin-bottom:0}.username-list .username:not(:last-child)::after{content:\", \"}.username-list .username:last-child::after{content:\".\"}\n    "]
        }), 
        __metadata('design:paramtypes', [inventory_1.Inventory])
    ], DatagridSortingDemo);
    return DatagridSortingDemo;
}());
exports.DatagridSortingDemo = DatagridSortingDemo;
